@@ -96,7 +96,6 @@ int statit = 0;
 int timeout = 1;
 char *redirect_url = NULL;
 char *squidguard = NULL;
-char *log_file = NULL;
 char *clamd_local = NULL;
 char *clamd_ip = NULL;
 char *clamd_port = NULL;
@@ -806,6 +805,7 @@ xfree(void *s)
 {
     if (s != NULL)
         free(s);
+    s = NULL;
 }
 
 /* Remove spaces and tabs from beginning and end of a string */
@@ -1063,22 +1063,24 @@ load_patterns()
 	ci_debug_printf(0, "ERROR load_patterns: Can't close configuration file\n");
 
   /* Set default values */
-  if (clamd_ip == NULL) {
-	clamd_ip = (char *) malloc (sizeof (char) * SMALL_CHAR);
-	if(clamd_ip == NULL) {
-		ci_debug_printf(0, "FATAL load_patterns: unable to allocate memory in load_patterns()\n");
-		return 0;
-	}
-	xstrncpy(clamd_ip, CLAMD_SERVER, SMALL_CHAR);
-  }
+  if (clamd_local == NULL) {
+	  if (clamd_ip == NULL) {
+		clamd_ip = (char *) malloc (sizeof (char) * SMALL_CHAR);
+		if(clamd_ip == NULL) {
+			ci_debug_printf(0, "FATAL load_patterns: unable to allocate memory in load_patterns()\n");
+			return 0;
+		}
+		xstrncpy(clamd_ip, CLAMD_SERVER, SMALL_CHAR);
+	  }
 
-  if (clamd_port == NULL) {
-	clamd_port = (char *) malloc (sizeof (char) * LOW_CHAR);
-	if(clamd_port == NULL) {
-		ci_debug_printf(0, "FATAL load_patterns: unable to allocate memory in load_patterns()\n");
-		return 0;
-	}
-	xstrncpy(clamd_port, CLAMD_PORT, LOW_CHAR);
+	  if (clamd_port == NULL) {
+		clamd_port = (char *) malloc (sizeof (char) * LOW_CHAR);
+		if(clamd_port == NULL) {
+			ci_debug_printf(0, "FATAL load_patterns: unable to allocate memory in load_patterns()\n");
+			return 0;
+		}
+		xstrncpy(clamd_port, CLAMD_PORT, LOW_CHAR);
+	  }
   }
 
   return 1;
@@ -1212,22 +1214,6 @@ add_pattern(char *s)
 		return 1;
 	}
 
-	/* Path to log file */
-	if(strcmp(type, "logfile") == 0) {
-		log_file = (char *) malloc (sizeof (char) * LOW_BUFF);
-		if (log_file == NULL) {
-			fprintf(stderr, "unable to allocate memory in add_to_patterns()\n");
-			xfree(type);
-			xfree(first);
-			return 0;
-		} else {
-			xstrncpy(log_file, first, LOW_BUFF);
-		}
-		xfree(type);
-		xfree(first);
-		return 1;
-	}
-
 	if(strcmp(type, "clamd_ip") == 0) {
 		clamd_ip = (char *) malloc (sizeof (char) * SMALL_CHAR);
 		if (clamd_ip == NULL) {
@@ -1407,12 +1393,11 @@ char *http_content_type(ci_request_t * req)
 void
 free_global ()
 {
+     xfree(clamd_local);
      xfree(clamd_ip);
      xfree(clamd_port);
      xfree(clamd_curr_ip);
-     xfree(clamd_local);
      xfree(redirect_url);
-     xfree(log_file);
      if (patterns != NULL) {
 	while (pattc > 0) {
 	   pattc--;
@@ -1420,6 +1405,7 @@ free_global ()
 	   xfree(patterns[pattc].pattern);
 	}
 	free(patterns);
+	patterns = NULL;
      }
 }
 
